import { useEffect } from 'react';
import { loader, useMonaco } from '@monaco-editor/react';
import { registerDolphinDBLanguage } from '../index.js';
import { setColorMap } from '../tokenizer.js';
import useIsUnmounted from './use-is-unmounted.js';
let monacoInitialized = false;
let initMonacoPromise = null;
export function useInitDolphinDBMonaco({ beforeMonacoInit, onMonacoInit, onMonacoInitFailed, dolphinDBLanguageOptions }) {
    const isUnmountedRef = useIsUnmounted();
    function setInitMonacoPromiseThenAndCatch(p) {
        p.then(monaco => {
            if (!isUnmountedRef.current)
                onMonacoInit?.(monaco);
        })
            .catch(err => {
            onMonacoInitFailed?.(err);
        })
            .finally(() => {
            initMonacoPromise = null;
        });
    }
    // 已完成初始化
    if (monacoInitialized)
        return;
    // 正在初始化
    if (initMonacoPromise) {
        setInitMonacoPromiseThenAndCatch(initMonacoPromise);
        return;
    }
    // 未初始化
    initMonacoPromise = (async () => {
        await beforeMonacoInit?.();
        const monaco = await loader.init();
        await registerDolphinDBLanguage(monaco, dolphinDBLanguageOptions);
        await document.fonts.ready;
        monacoInitialized = true;
        return monaco;
    })();
    setInitMonacoPromiseThenAndCatch(initMonacoPromise);
}
/** update editor on options change */
export function useDolphinDBMonacoOptions({ theme }) {
    const monaco = useMonaco();
    useEffect(() => {
        if (monaco)
            setColorMap(monaco, theme ?? 'light');
    }, [monaco, theme]);
}
//# sourceMappingURL=shared.js.map